@@ -189,6 +189,8 @@ namespace ZmartRecipients
       Out & out = Zypper::instance().out();
       out.progressStart("preload-progress", _("Preloading Packages") );
       _last_drate_avg = -1;
+      _lastProgressVal = -1;
+      _lastProgressString.clear();
     }
 
     bool progress( int value, const UserData &userData ) override
@@ -214,6 +216,8 @@ namespace ZmartRecipients
         outstr << " (" << zypp::ByteCount( userData.get<double>("dbps_current") ) << "/s)";
       outstr << ']';
 
+      _lastProgressString = outstr;
+      _lastProgressVal    = value;
       zypper.out().progress("preload-progress", outstr, value );
       if ( userData.haskey("dbps_avg") )
         _last_drate_avg = userData.get<double>("dbps_avg");
@@ -230,6 +234,7 @@ namespace ZmartRecipients
       if ( _be_quiet )
         return;
 
+      /*
       zypp::str::Str outstr;
       outstr << _("Preloading:") << " ";
       if ( Zypper::instance().out().verbosity() == Out::DEBUG  && userData.haskey("Url") )
@@ -238,6 +243,8 @@ namespace ZmartRecipients
         outstr << localfile.basename();
 
       Zypper::instance().out().info() << ( ColorContext::MSG_STATUS << outstr );
+      redrawProgress ();
+      */
     }
 
     /**
@@ -260,28 +267,34 @@ namespace ZmartRecipients
         outstr << localfile.basename();
       outstr << ' ';
       outstr << '[';
+
+      constexpr auto descriptionOrString = []( const callback::UserData &data, const std::string &alternative ){
+        return data.get<std::string>("description", alternative);
+      };
+
       switch ( error ) {
         case zypp::media::CommitPreloadReport::NO_ERROR: {
           // Translator: prefetch progress bar result: ".............[done]"
-          outstr << _("done");
+          outstr << descriptionOrString( userData, _("done") );
           break;
         }
         case zypp::media::CommitPreloadReport::NOT_FOUND: {
           // Translator: prefetch progress bar result: "........[not found]"
-          outstr << CHANGEString( _("not found") );
+          outstr << CHANGEString( descriptionOrString( userData, _("not found") ) );
           break;
         }
         case zypp::media::CommitPreloadReport::IO:
         case zypp::media::CommitPreloadReport::ACCESS_DENIED:
         case zypp::media::CommitPreloadReport::ERROR: {
           // Translator: prefetch progress bar result: "............[error]"
-          outstr << NEGATIVEString( _("error") );
+          outstr << NEGATIVEString( descriptionOrString( userData, _("error") ) );
           break;
         }
       }
       outstr << ']';
 
       Zypper::instance().out().info() << ( ColorContext::MSG_STATUS << outstr );
+      redrawProgress ();
     }
 
     void finish( Result res, const UserData & ) override
@@ -312,8 +325,16 @@ namespace ZmartRecipients
     }
 
   private:
+
+    void redrawProgress() {
+      if ( _lastProgressVal >= 0 )
+        Zypper::instance().out().progress("preload-progress", _lastProgressString, _lastProgressVal );
+    }
+
     bool _be_quiet;
     double _last_drate_avg;
+    int _lastProgressVal = -1;
+    std::string _lastProgressString;
   };
 
 
