@@ -47,6 +47,14 @@ namespace env
 namespace	// subcommand detetction
 {///////////////////////////////////////////////////////////////////
 
+  inline std::vector<Pathname> pathDirsIf( bool yesno_r )
+  {
+    std::vector<Pathname> ret;
+    if ( yesno_r )
+      str::split( env::PATH(), std::back_inserter(ret), ":" );
+    return ret;
+  }
+
   /** Strictly compare \ref SubcommandOptions::Detected according to _cmd. */
   struct DetectedCommandsCompare
   {
@@ -61,30 +69,33 @@ namespace	// subcommand detetction
   using CommandSummaries = std::map<std::string,std::string>;
 
   /** Get command summaries for help. */
-  inline CommandSummaries getCommandsummaries( const DetectedCommands & commands_r )
+  inline CommandSummaries getCommandsummaries( const DetectedCommands & commands_r, bool withPath = false )
   {
     CommandSummaries ret;
     for ( auto & cmd : commands_r ) {
-      std::string sum { ExternalProgram( { "man", "-f", cmd._name }, ExternalProgram::Discard_Stderr ).receiveLine() };
+      std::string sum { str::rtrim( ExternalProgram( { "man", "-f", cmd._name }, ExternalProgram::Discard_Stderr ).receiveLine() ) };
+
       if ( ! sum.empty() ) {
-	// # man -f zypper
-	// zypper (8)           - Command-line interface to ZYpp system management library (libzypp)
-	static const std::string_view sep { " - " };
-	std::string::size_type pos = sum.find( sep );
-	if ( pos != std::string::npos )
-	  sum.erase( 0, pos + sep.size() );
+        // # man -f zypper
+        // zypper (8)           - Command-line interface to ZYpp system management library (libzypp)
+        static const std::string_view sep { " - " };
+        std::string::size_type pos = sum.find( sep );
+        if ( pos != std::string::npos )
+          sum.erase( 0, pos + sep.size() );
       }
       else {
-	// translators: %1% is the name of the command which has no man page available.
-	static str::Format fmt( "<"+ LOWLIGHTString(_("No manual entry for %1%")).str() + ">" );
-	sum = ( fmt % cmd._name ).str();
+        // translators: %1% is the name of the command which has no man page available.
+        static str::Format fmt( "<"+ LOWLIGHTString(_("No manual entry for %1%")).str() + ">" );
+        sum = ( fmt % cmd._name ).str();
       }
-      ret[cmd._cmd] = sum;
+      ret[cmd._cmd] = std::move(sum);
+      if ( withPath )
+        ret[cmd._cmd] += "\n("+(cmd._path/cmd._name).asString()+")";
     }
     return ret;
   }
 
-  inline std::ostream & dumpDetectedCommandsOn( std::ostream & str, const DetectedCommands & commands_r )
+  inline std::ostream & dumpDetectedCommandsOn( std::ostream & str, const DetectedCommands & commands_r, bool withPath = false )
   {
     CommandHelpFormater fmt;
 
@@ -92,8 +103,8 @@ namespace	// subcommand detetction
       fmt.gDef( "<"+std::string(_("none"))+">" );
     }
     else {
-      for ( const auto & p : getCommandsummaries( std::move(commands_r) ) ) {
-	fmt.gDef( p.first, p.second );
+      for ( const auto & p : getCommandsummaries( commands_r, withPath ) ) {
+        fmt.gDef( p.first, p.second );
       }
     }
 
@@ -155,58 +166,50 @@ namespace	// subcommand detetction
       return;
 
     filesystem::dirForEach( dir_r,
-			    [&fnc_r]( const Pathname & dir_r, std::string name_r )->bool
-			    {
-			      SubcommandOptions::Detected cmd { detectSubcommand( dir_r, std::move(name_r) ) };
-			      if ( ! cmd._cmd.empty() )
-				fnc_r( std::move(cmd) );
-			      return true;
-			    } );
+                            [&fnc_r]( const Pathname & dir_r, std::string name_r )->bool
+                            {
+                              SubcommandOptions::Detected cmd { detectSubcommand( dir_r, std::move(name_r) ) };
+                              if ( ! cmd._cmd.empty() )
+                                fnc_r( std::move(cmd) );
+                              return true;
+                            } );
   }
 
   /* Just the command names for the short help. */
-  inline void collectAllSubcommandNames( std::set<std::string> & allCommands_r )
+  inline void collectAllSubcommandNames( std::set<std::string> & allCommands_r, const std::vector<Pathname> pathDirs_r )
   {
     auto collectSubcommandsIn = [&allCommands_r]( const Pathname & dir_r ) {
       detectSubcommandsIn( dir_r,
-			   [&allCommands_r]( SubcommandOptions::Detected cmd_r )
-			   {
-			     allCommands_r.insert( std::move(cmd_r._cmd) );
-			   } );
+                           [&allCommands_r]( SubcommandOptions::Detected cmd_r )
+                           {
+                             allCommands_r.insert( std::move(cmd_r._cmd) );
+                           } );
     };
 
     collectSubcommandsIn( SubcommandOptions::_execdir );
 
-    std::set<Pathname> dirs;
-    str::split( env::PATH(), std::inserter(dirs,dirs.end()), ":" );
-    for ( const auto & dir : dirs )
-    {
+    for ( const auto & dir : pathDirs_r )
       collectSubcommandsIn( dir );
-    }
   }
 
   /* The command details for the long help. */
   inline void collectAllSubcommands( DetectedCommands & execdirCommands_r,
-				     DetectedCommands & pathCommands_r )
+                                     DetectedCommands & pathCommands_r, const std::vector<Pathname> pathDirs_r )
   {
     // Commands in _execdir shadow commands in the path.
     auto collectSubcommandsIn = []( const Pathname & dir_r, DetectedCommands & commands_r, DetectedCommands * shaddow_r = nullptr ) {
       detectSubcommandsIn( dir_r,
-			   [&commands_r,shaddow_r]( SubcommandOptions::Detected cmd_r )
-			   {
-			     if ( ! ( shaddow_r && shaddow_r->count( cmd_r ) ) )
-			       commands_r.insert( std::move(cmd_r) );
-			   } );
+                           [&commands_r,shaddow_r]( SubcommandOptions::Detected cmd_r )
+                           {
+                             if ( ! ( shaddow_r && shaddow_r->count( cmd_r ) ) )
+                               commands_r.insert( std::move(cmd_r) );
+                           } );
     };
 
     collectSubcommandsIn( SubcommandOptions::_execdir, execdirCommands_r );
 
-    std::set<Pathname> dirs;
-    str::split( env::PATH(), std::inserter(dirs,dirs.end()), ":" );
-    for ( const auto & dir : dirs )
-    {
+    for ( const auto & dir : pathDirs_r )
       collectSubcommandsIn( dir, pathCommands_r, &execdirCommands_r );
-    }
   }
 
 } // namespace
@@ -242,11 +245,11 @@ namespace	// command execution
       std::string ret;
       if ( !_args.empty() )
       {
-	for ( const auto & arg : _args )
-	{
-	  if ( !ret.empty() ) ret += " ";
-	  ret += quotearg( arg );
-	}
+        for ( const auto & arg : _args )
+        {
+          if ( !ret.empty() ) ret += " ";
+          ret += quotearg( arg );
+        }
       }
       return ret;
     }
@@ -317,14 +320,14 @@ namespace	// command execution
 
       if ( ! _args.empty() )
       {
-	const char * argv[_args.size()+1];
-	unsigned idx = 0;
-	for( ; idx < _args.size(); ++idx )
-	{ argv[idx] = _args[idx].c_str(); }
-	 argv[idx] = nullptr;
+        const char * argv[_args.size()+1];
+        unsigned idx = 0;
+        for( ; idx < _args.size(); ++idx )
+        { argv[idx] = _args[idx].c_str(); }
+         argv[idx] = nullptr;
 
-	if ( ! execvp( argv[0], (char**)argv ) )
-	{ _exit (0); }	// does not happen!
+        if ( ! execvp( argv[0], (char**)argv ) )
+        { _exit (0); }	// does not happen!
       }
       cerr << ( str::Format(_("cannot exec %1% (%2%)")) % command() % strerror(errno) ) << endl;
       _exit (128);
@@ -379,7 +382,7 @@ namespace	// command execution
       WAR <<     ( str::Format(txt)    % command() % code % strsignal(code) ) << endl;
       _execError = str::Format(_(txt)) % command() % code % strsignal(code);
       if ( WCOREDUMP(status) )
-	_execError += str::Format(" (%1)") % _("core dumped");
+        _execError += str::Format(" (%1)") % _("core dumped");
       _exitStatus = 128 + code;
     }
     else if ( WIFEXITED(status) )
@@ -387,16 +390,16 @@ namespace	// command execution
       code = WEXITSTATUS(status);
       if ( code )
       {
-	// translators: %1% - command name or path
-	// translators: %2% - exit code (number)
-	const char * txt = N_("%1% exited with status %2%");
-	WAR <<     ( str::Format(txt)    % command() % code ) << endl;
-	_execError = str::Format(_(txt)) % command() % code;
+        // translators: %1% - command name or path
+        // translators: %2% - exit code (number)
+        const char * txt = N_("%1% exited with status %2%");
+        WAR <<     ( str::Format(txt)    % command() % code ) << endl;
+        _execError = str::Format(_(txt)) % command() % code;
       }
       else
       {
-	DBG << command() << " successfully completed" << endl;
-	_execError.clear(); // empty if running or successfully completed
+        DBG << command() << " successfully completed" << endl;
+        _execError.clear(); // empty if running or successfully completed
       }
       _exitStatus = code;
     }
@@ -438,39 +441,45 @@ std::ostream & SubcommandOptions::showHelpOn( std::ostream & out ) const
       // translators: %1% is a directory name
       out << str::Format(_(
         "Zypper subcommands are standalone executables that live in the\n"
-	"zypper_execdir ('%1%').\n"
-	"\n"
-	"For subcommands zypper provides a wrapper that knows where the\n"
-	"subcommands live, and runs them by passing command-line arguments\n"
-	"to them.\n"
-	"\n"
-	"If a subcommand is not found in the zypper_execdir, the wrapper\n"
-	"will look in the rest of your $PATH for it. Thus, it's possible\n"
-	"to write local zypper extensions that don't live in system space.\n"
+        "zypper_execdir ('%1%').\n"
+        "\n"
+        "For subcommands zypper provides a wrapper that knows where the\n"
+        "subcommands live, and runs them by passing command-line arguments\n"
+        "to them.\n"
+        "\n"
+        "If a subcommand is not found in the zypper_execdir, the wrapper\n"
+        "will look in the rest of your $PATH for it. Thus, it's possible\n"
+        "to write local zypper extensions that don't live in system space.\n"
       ) ) % _execdir;
       out << endl;
 
       // translators: %1% is a zypper command
       out << str::Format(_(
-	"Using zypper global-options together with subcommands, as well as\n"
-	"executing subcommands in '%1%' is currently not supported.\n"
+        "Using zypper global-options together with subcommands, as well as\n"
+        "executing subcommands in '%1%' is currently not supported.\n"
       ) ) % "zypper shell";
       out << endl;
 
 
       DetectedCommands execdirCommands;
       DetectedCommands pathCommands;
-      collectAllSubcommands( execdirCommands, pathCommands );
+      collectAllSubcommands( execdirCommands, pathCommands, pathDirsIf( _zypper.config().seach_subcommand_in_path ) );
 
       // translators: headline of an enumeration; %1% is a directory name
-      out << str::Format(_("Available zypper subcommands in '%1%'") ) % _execdir << endl;
+      out << str::Format(_("Available zypper subcommands in '%1%'") ) % _execdir << ":" << endl;
       out << endl;
       dumpDetectedCommandsOn( out, execdirCommands ) << endl;
 
-      // translators: headline of an enumeration
-      out << _("Zypper subcommands available from elsewhere on your $PATH") << endl;
-      out << endl;
-      dumpDetectedCommandsOn( out, pathCommands ) << endl;
+      if ( _zypper.config().seach_subcommand_in_path ) {
+        // translators: headline of an enumeration
+        out << _("Zypper subcommands available from elsewhere on your $PATH") << ":" << endl;
+        out << endl;
+        dumpDetectedCommandsOn( out, pathCommands, /*withPath*/true ) << endl;
+      }
+      else {
+        out << _("Using zypper subcommands available from elsewhere on your $PATH is disabled in zypper.conf.") << endl;
+        out << endl;
+      }
 
       // translators: helptext; %1% is a zypper command
       out << str::Format(_("Type '%1%' to get subcommand-specific help if available.") ) % "zypper help <subcommand>" << endl;
@@ -478,9 +487,9 @@ std::ostream & SubcommandOptions::showHelpOn( std::ostream & out ) const
     else
     {
       std::set<std::string> allCommands;
-      collectAllSubcommandNames( allCommands );
+      collectAllSubcommandNames( allCommands, pathDirsIf( _zypper.config().seach_subcommand_in_path ) );
       if ( ! allCommands.empty() )
-	dumpRange( out, allCommands.begin(),allCommands.end(), "", "", ", ", "", "" );
+        dumpRange( out, allCommands.begin(),allCommands.end(), "", "", ", ", "", "" );
     }
   }
   else
@@ -494,9 +503,9 @@ std::ostream & SubcommandOptions::showHelpOn( std::ostream & out ) const
       Zypper & _zypper = Zypper::instance();
       if ( cmd.exitStatus() != 16 )	// man already returned 'No manual entry for...'
       {
-	_zypper.out().error( cmd.execError() );
-	// translators: %1% - command name
-	_zypper.out().info( str::Format(_("Manual entry for %1% can't be shown")) % _detected._name );
+        _zypper.out().error( cmd.execError() );
+        // translators: %1% - command name
+        _zypper.out().info( str::Format(_("Manual entry for %1% can't be shown")) % _detected._name );
       }
       _zypper.setExitCode( cmd.exitStatus() );
     }
@@ -509,7 +518,10 @@ SubCmd::SubCmd(std::vector<std::string> &&commandAliases_r , boost::shared_ptr<S
     std::move( commandAliases_r ),
     "subcommand",
     // translators: command summary: subcommand
-    _("Lists available subcommands."),
+    Zypper::instance().config().seach_subcommand_in_path
+    ? _("Lists available subcommands.")
+    : _("Lists available subcommands. Using zypper subcommands found on your $PATH is disabled in zypper.conf.")
+    ,
     "", //no help text, its created on demand
     DisableAll
     ),
@@ -542,22 +554,20 @@ bool SubCmd::isSubcommand(const std::string &strval_r )
   if ( testAndRememberSubcommand( SubcommandOptions::_execdir, execname, strval_r ) )
     return true;
 
-  // Search in $PATH...
-  std::vector<Pathname> dirs;
-  str::split( env::PATH(), std::back_inserter(dirs), ":" );
-  for ( const auto & dir : dirs )
-  {
-    if ( testAndRememberSubcommand( dir, execname, strval_r ) )
-      return true;
+  if ( Zypper::instance().config().seach_subcommand_in_path ) {
+    // Search in $PATH...
+    for ( const auto & dir : pathDirsIf( true ) ) {
+      if ( testAndRememberSubcommand( dir, execname, strval_r ) )
+        return true;
+    }
   }
-
   return false;
 }
 
 CommandSummaries SubCmd::getSubcommandSummaries()
 {
   DetectedCommands detetctedCommands;
-  collectAllSubcommands( detetctedCommands, detetctedCommands ); // all in one is ok
+  collectAllSubcommands( detetctedCommands, detetctedCommands, pathDirsIf( Zypper::instance().config().seach_subcommand_in_path ) ); // all in one is ok
   return getCommandsummaries( detetctedCommands );
 }
 
