@@ -1,7 +1,7 @@
 #include <iostream>
 #include <signal.h>
 #include <poll.h>
-//#include <readline/readline.h>
+#include <readline/readline.h>
 
 #include <zypp/base/LogTools.h>
 #include <zypp/base/LogControl.h>
@@ -34,6 +34,34 @@ namespace env
 static const char* exit_requested_once_str;
 static const char* exit_requested_twice_str;
 
+int my_getc_function( FILE * f )
+{
+  struct pollfd fds[1];
+  Zypper & zypper( Zypper::instance( true ) );
+
+  while ( true ) {
+    fds[0].fd = fileno(f);
+    fds[0].events = POLLIN;
+
+    int retval = poll( fds, 1, 500 );
+
+    if ( retval == -1 ) {
+      return 0;             // make readline evaluate any pending signals
+    } else if ( retval ) {
+      return rl_getc( f );  // get next char
+    } else {
+      if ( zypper.exitRequested() ) {
+        return -1;          // exit
+      }
+    }
+  }
+}
+
+void readline_setup()
+{
+  rl_getc_function = &my_getc_function;
+}
+
 void signal_handler( int sig )
 {
   // Do NOT write to the logfiles or use a iostream, we can NOT call into malloc here and
@@ -81,7 +109,7 @@ void signal_nopipe( int sig )
 }
 
 int main( int argc, char **argv )
-{
+try {
   struct Bye {
     ~Bye() {
       MIL << "===== Exiting main("<<exitcode<<") =====" << endl;
@@ -134,6 +162,8 @@ int main( int argc, char **argv )
   if ( ::signal( SIGPIPE, signal_nopipe ) == SIG_ERR )
     zypper.out().error("Failed to set SIGPIPE handler.");
 
+  readline_setup(); // bsc#1226493# let readline abort on Ctrl-C
+
   try
   {
     static RpmCallbacks rpm_callbacks;
@@ -165,3 +195,10 @@ int main( int argc, char **argv )
     exitcode = zypper.exitInfoCode();	// propagate refresh errors even if main action succeeded
   return exitcode;
 }
+catch (...) {
+  // https://en.cppreference.com/w/cpp/language/throw#stack_unwinding
+  // ... It is implementation-defined whether any stack unwinding
+  //     takes place for uncaught exceptions. ...
+  // And so we catch them to allow any RAII driven cleanup to perform.
+  throw;
+}
