@@ -215,7 +215,6 @@ bool refresh_raw_metadata( Zypper & zypper, const RepoInfo & repo, bool force_do
 
   // bsc#1123967
   // Temporarily disconnect, if errors happen we just skip the repository
-#define DISABLE_ScopedDisableMediaChangeReport_GUARD
   callback::TempConnect<zypp::media::MediaChangeReport> tempDisconnect;
 
   try
@@ -228,13 +227,8 @@ bool refresh_raw_metadata( Zypper & zypper, const RepoInfo & repo, bool force_do
                          Out::HIGH );
       if ( !repo.baseUrlsEmpty() )
       {
-#ifndef DISABLE_ScopedDisableMediaChangeReport_GUARD
-        Disabled because of fix for bsc#1123967
-        // Suppress (interactive) media::MediaChangeReport if we in have multiple basurls (>1)
-        media::ScopedDisableMediaChangeReport guard( repo.baseUrlsSize() > 1 );
-#endif
-
-        for ( RepoInfo::urls_const_iterator it = repo.baseUrlsBegin(); it != repo.baseUrlsEnd(); )
+        const auto &repoOrigins = repo.repoOrigins();
+        for ( auto it = repoOrigins.begin(); it != repoOrigins.end(); )
         {
           try
           {
@@ -271,10 +265,10 @@ bool refresh_raw_metadata( Zypper & zypper, const RepoInfo & repo, bool force_do
           catch ( const Exception & e )
           {
             ZYPP_CAUGHT( e );
-            Url badurl( *it );
-            if ( ++it == repo.baseUrlsEnd() )
+            std::vector<OriginEndpoint> badurls( it->begin(), it->end() );
+            if ( ++it == repoOrigins.end() )
               ZYPP_RETHROW( e );
-            ERR << badurl << " doesn't look good. Trying another url (" << *it << ")." << endl;
+            ERR << badurls << " doesn't look good. Trying another url (" << *it << ")." << endl;
           }
         }
       }
@@ -1147,7 +1141,7 @@ void clean_repos(Zypper & zypper , std::vector<std::string> specificRepos, Clean
 
 // ----------------------------------------------------------------------------
 
-bool add_repo( Zypper & zypper, RepoInfo & repo, bool noCheck )
+bool add_repo( Zypper & zypper, RepoInfo & repo, const TriBool & forcedProbe )
 {
   RepoManager & manager = zypper.repoManager();
   RuntimeData & gData = zypper.runtimeData();
@@ -1179,7 +1173,7 @@ bool add_repo( Zypper & zypper, RepoInfo & repo, bool noCheck )
     // reset the gData.current_repo when going out of scope
     struct Bye { ~Bye() { Zypper::instance().runtimeData().current_repo = RepoInfo(); } } reset __attribute__ ((__unused__));
 
-    manager.addRepository( repo );
+    manager.addRepository( repo, forcedProbe );
     repo = manager.getRepo( repo );
   }
   catch ( const repo::RepoInvalidAliasException & e )
@@ -1263,7 +1257,12 @@ bool add_repo( Zypper & zypper, RepoInfo & repo, bool noCheck )
 
   if ( is_cd )
   {
-    if ( ! noCheck )
+    if ( forcedProbe == false ) // TriBool! - explicitly false
+    {
+      zypper.out().info( str::Format(_("Reading data from '%s' media is delayed until next refresh.")) % repo.asUserString(),
+                         " [--no-check]" );
+    }
+    else
     {
       zypper.out().info( str::Format(_("Reading data from '%s' media")) % repo.asUserString() );
       bool error = refresh_raw_metadata( zypper, repo, false );
@@ -1277,11 +1276,6 @@ bool add_repo( Zypper & zypper, RepoInfo & repo, bool noCheck )
         return false;
       }
     }
-    else
-    {
-      zypper.out().info( str::Format(_("Reading data from '%s' media is delayed until next refresh.")) % repo.asUserString(),
-                         " [--no-check]" );
-    }
   }
   return true;
 }
@@ -1293,7 +1287,7 @@ void add_repo_by_url( Zypper & zypper,
                       const std::string & alias,
                       const RepoServiceCommonOptions &opts,
                       const RepoProperties &repoProps,
-                      bool noCheck )
+                      const TriBool & forcedProbe )
 {
   MIL << "going to add repository by url (alias=" << alias << ", url=" << url << ")" << endl;
 
@@ -1319,7 +1313,7 @@ void add_repo_by_url( Zypper & zypper,
   if ( gpgCheck != RepoInfo::GpgCheck::indeterminate )
     repo.setGpgCheck( gpgCheck );
 
-  if ( add_repo( zypper, repo, noCheck ) )
+  if ( add_repo( zypper, repo, forcedProbe ) )
     repoPrioSummary( zypper );
 }
 
@@ -1329,7 +1323,7 @@ void add_repo_from_file( Zypper & zypper,
                          const std::string & repo_file_url,
                          const RepoServiceCommonOptions &opts,
                          const RepoProperties &repoProps,
-                         bool noCheck )
+                         const TriBool & forcedProbe )
 {
   Url url = make_url( repo_file_url );
   if ( !url.isValid() )
@@ -1406,7 +1400,7 @@ void add_repo_from_file( Zypper & zypper,
     if ( repoProps._priority >= 1 )
       repo.setPriority( repoProps._priority );
 
-    if ( add_repo( zypper, repo, noCheck ) )
+    if ( add_repo( zypper, repo, forcedProbe ) )
       addedAtLeastOneRepository = true;
   }
 
