@@ -282,7 +282,7 @@ static void list_patterns_xml( Zypper & zypper, SolvableFilterMode mode_r )
       continue;
     if ( !isInstalled && installed_only && !notinst_only )
       continue;
-    if ( repofilter && pi.repository().info().name() == "@System" )
+    if ( repofilter && pi.repository().isSystemRepo() )
       continue;
 
     Pattern::constPtr pattern = asKind<Pattern>(pi.resolvable());
@@ -320,8 +320,7 @@ static void list_pattern_table( Zypper & zypper, SolvableFilterMode mode_r )
       else if ( !isInstalled && installed_only && !notinst_only )
         continue;
 
-      const std::string & piRepoName( pi.repoInfo().name() );
-      if ( repofilter && piRepoName == "@System" )
+      if ( repofilter && pi.repository().isSystemRepo() )
         continue;
 
       Pattern::constPtr pattern = asKind<Pattern>(pi.resolvable());
@@ -333,7 +332,7 @@ static void list_pattern_table( Zypper & zypper, SolvableFilterMode mode_r )
           << computeStatusIndicator( pi )
           << pi.name()
           << pi.edition()
-          << piRepoName
+          << pi.repository().asUserString()
           << string_weak_status(pi.status()) );
     }
   }
@@ -356,6 +355,14 @@ void list_patterns(Zypper & zypper , SolvableFilterMode mode_r)
 
 void list_packages(Zypper & zypper , ListPackagesFlags flags_r )
 {
+  // These flags need a solver run to be computed
+  static constexpr ListPackagesFlags maskNeedSolv = {
+    ListPackagesBits::ShowOrphaned
+    | ListPackagesBits::ShowSuggested
+    | ListPackagesBits::ShowRecommended
+    | ListPackagesBits::ShowUnneeded
+  };
+
   MIL << "Going to list packages." << std::endl;
   Table tbl;
 
@@ -363,22 +370,35 @@ void list_packages(Zypper & zypper , ListPackagesFlags flags_r )
   bool showInstalled = !flags_r.testFlag( ListPackagesBits::HideInstalled ); //installed_only || !uninstalled_only;
   bool showUninstalled = !flags_r.testFlag( ListPackagesBits::HideNotInstalled ); //uninstalled_only || !installed_only;
 
+  bool system = flags_r.testFlag( ListPackagesBits::ShowSystem );
   bool orphaned = flags_r.testFlag( ListPackagesBits::ShowOrphaned );
   bool suggested = flags_r.testFlag( ListPackagesBits::ShowSuggested );
   bool recommended = flags_r.testFlag( ListPackagesBits::ShowRecommended );
   bool unneeded = flags_r.testFlag( ListPackagesBits::ShowUnneeded );
-  bool check = ( orphaned || suggested || recommended || unneeded );
-  if ( check )
-  {
+  bool byAuto = flags_r.testFlag( ListPackagesBits::ShowByAuto );
+  bool byUser = flags_r.testFlag( ListPackagesBits::ShowByUser );
+  bool check = ( flags_r & ( maskNeedSolv | ListPackagesBits::ShowSystem | ListPackagesBits::ShowByAuto | ListPackagesBits::ShowByUser ) );
+  if ( flags_r & maskNeedSolv ) {
     God->resolver()->resolvePool();
   }
-  auto checkStatus = [=]( ResStatus status_r )->bool {
-    return ( ( orphaned && status_r.isOrphaned() )
-          || ( suggested && status_r.isSuggested() )
-          || ( recommended && status_r.isRecommended() )
-          || ( unneeded && status_r.isUnneeded() ) );
+  auto checkStatus = [=]( const PoolItem & pi_r, bool isipi=false )->bool {
+    // isipi : prevent returning true if identical installed items are tested.
+    const ResStatus & status { pi_r.status() };
+    if ( ( system && !isipi && pi_r.repository().isSystemRepo() )
+      || ( orphaned && status.isOrphaned() )
+      || ( suggested && status.isSuggested() )
+      || ( recommended && status.isRecommended() )
+      || ( unneeded && status.isUnneeded() ) ) {
+      return true;
+    } else if ( status.isInstalled() ) {
+      return ( byAuto && pi_r.identIsAutoInstalled() ) || ( byUser && not pi_r.identIsAutoInstalled() );
+    }
+    return false;
   };
 
+  // if both --system and --orphaned are given, tag orphaned system packages
+  bool tagOrphaned = system && orphaned;
+
   for( const auto & sel : God->pool().proxy().byKind<Package>() )
   {
     // filter on selectable level
@@ -402,28 +422,27 @@ void list_packages(Zypper & zypper , ListPackagesFlags flags_r )
         // not whole selectables
         if ( pi.status().isInstalled() )
         {
-          if ( ! checkStatus( pi.status() ) )
+          if ( ! checkStatus( pi ) )
             continue;
         }
         else
         {
           PoolItem ipi( sel->identicalInstalledObj( pi ) );
-          if ( !ipi || !checkStatus( ipi.status() ) )
-            if ( ! checkStatus( pi.status() ) )
+          if ( !ipi || !checkStatus( ipi, true ) )
+            if ( ! checkStatus( pi ) )
               continue;
         }
       }
 
-      const std::string & piRepoName( pi->repository().info().name() );
-      if ( repofilter && piRepoName == "@System" )
+      if ( repofilter && pi.repository().isSystemRepo() )
         continue;
 
       tbl << ( TableRow()
-          << computeStatusIndicator( pi, sel )
-          << piRepoName
-          << pi->name()
-          << pi->edition().asString()
-          << pi->arch().asString() );
+          << (computeStatusIndicator( pi, sel )+std::string(tagOrphaned && pi.status().isOrphaned()?" (o)":""))
+          << pi.repository().asUserString()
+          << pi.name()
+          << pi.edition().asString()
+          << pi.arch().asString() );
     }
   }
 
@@ -446,6 +465,9 @@ void list_packages(Zypper & zypper , ListPackagesFlags flags_r )
       tbl.sort( 2 ); // Name
 
     cout << tbl;
+
+    if ( tagOrphaned )
+      Zypper::instance().out().notePar( 4, "(o) = orphaned" );
   }
 }
 
@@ -462,7 +484,7 @@ void list_products_xml( Zypper & zypper, SolvableFilterMode mode_r, const std::v
       continue;
     else if ( !pi.status().isInstalled() && installed_only )
       continue;
-    if ( repofilter && pi.repository().info().name() == "@System" )
+    if ( repofilter && pi.repository().isSystemRepo() )
       continue;
     Product::constPtr product = asKind<Product>(pi.resolvable());
     cout << asXML( *product, pi.status().isInstalled(), fwdTags ) << endl;
@@ -501,14 +523,13 @@ void list_product_table(Zypper & zypper , SolvableFilterMode mode_r)
       if ( ( installed_only && !iType ) || ( notinst_only && iType) )
         continue;
 
-      const std::string & piRepoName( pi.repoInfo().name() );
-      if ( repofilter && piRepoName == "@System" )
+      if ( repofilter && pi.repository().isSystemRepo() )
         continue;
 
       // NOTE: 'Is Base' is available in the installed object only.
       tbl << ( TableRow()
           << statusIndicator
-          << piRepoName
+          << pi.repository().asUserString()
           << pi.name()
           << pi.summary()	// full name (bnc #589333)
           << pi.edition()
