@@ -385,12 +385,12 @@ int parseCLI( const int argc, char * const *argv, const std::vector<CommandGroup
             if ( zypp::str::regex_match( scanned, what, rxexpr ) && what.size() >= 2 ) {
               if( opt.name != what[1] ) {
                 if ( onlyWarnOnAbbrevSwitches() ) {
-		  WAR << "Abbreviated commandline options will not be supported in future versions: --" << what[1] << ": use --" << opt.name << endl;
+                  WAR << "Abbreviated commandline options will not be supported in future versions: --" << what[1] << ": use --" << opt.name << endl;
 
                   // Since this message will be emitted before we know if the current output is XML or Normal we need to send this message to stderr
                   // to not break scripts that use xml output (bsc#1172925)
                   Zypper::instance().out().error( std::string( _("Warning: ") ) + legacyCLIStr( what[1], opt.name, LegacyCLIMsgType::Abbreviated ) );
-		} else
+                } else
                   ZYPP_THROW( UnknownFlagException( scanned ) );
               }
             } else {
@@ -410,7 +410,7 @@ int parseCLI( const int argc, char * const *argv, const std::vector<CommandGroup
           }
 
           if ( !conflictingList.empty() ) {
-            for ( const std::string conflicting : conflictingList ){
+            for ( const std::string &conflicting : conflictingList ){
               auto it = longOptIndex.find( conflicting );
               if ( it == longOptIndex.end() ) {
                 WAR << "Ignoring unknown option " << conflicting << " specified as conflicting flag for " << opt.name << endl;
