@@ -11,7 +11,6 @@
 
 #include <zypp/base/Logger.h>
 #include <zypp/base/String.h>
-#include <zypp/base/Easy.h>
 #include <zypp/base/Regex.h>
 #include <zypp/media/MediaManager.h>
 #include <zypp/ExternalProgram.h>
@@ -76,9 +75,9 @@ ResKindSet kindset_from( const std::list<std::string> & kindstrings )
 {
   ResKind kind;
   ResKindSet kinds;
-  for_( it, kindstrings.begin(), kindstrings.end() )
+  for ( const std::string & kindstring : kindstrings )
   {
-    kind = string_to_kind(*it);
+    kind = string_to_kind(kindstring);
     if ( kind == ResKind::nokind )
       continue;
     kinds.insert( kind );
@@ -414,7 +413,7 @@ bool looks_like_url( const std::string& s )
 Url make_url( const std::string & url_s )
 {
   Url u;
-  std::string urlstr( url::encode( url_s, URL_SAFE_CHARS ) );
+  std::string urlstr;
 
   if ( !url_s.empty() && !looks_like_url(url_s) )
   {
@@ -447,6 +446,10 @@ Url make_url( const std::string & url_s )
       return u;
     }
   }
+  else
+  {
+    urlstr = url::encode( url_s, URL_SAFE_CHARS, url::E_ENCODED );
+  }
 
   try {
     u = Url(urlstr);
