@@ -73,12 +73,11 @@
 
 #include "SolverRequester.h"
 
-using namespace std;
 using namespace zypp;
 
 bool hasPoolItem(
-    const set<PoolItem> & set,
-    const string & name,
+    const std::set<PoolItem> & set,
+    const std::string & name,
     const Edition & ed = Edition(),
     const Arch & arch = Arch_empty,
     const ResKind & kind = ResKind::package)
@@ -108,28 +107,34 @@ struct ApplyLock
   }
 };
 
-static TestSetup test(Arch_x86_64);
+struct TestInit {
+  TestInit()
+    : testSetup( std::make_unique<TestSetup>( Arch_x86_64 ) )
+  {
+    MIL << "============setup===========" << endl;
+    // fake target from a subset of the online 11.1 repo
+    testSetup->loadTargetRepo(TESTS_SRC_DIR "/data/openSUSE-11.1_subset");
+    testSetup->loadRepo(TESTS_SRC_DIR "/data/openSUSE-11.1", "main");
+    testSetup->loadRepo(TESTS_SRC_DIR "/data/misc", "misc");
+    testSetup->loadRepo(TESTS_SRC_DIR "/data/OBS_zypp_svn-11.1", "zypp");
 
-BOOST_AUTO_TEST_CASE(setup)
-{
-  MIL << "============setup===========" << endl;
-  // fake target from a subset of the online 11.1 repo
-  test.loadTargetRepo(TESTS_SRC_DIR "/data/openSUSE-11.1_subset");
-  test.loadRepo(TESTS_SRC_DIR "/data/openSUSE-11.1", "main");
-  test.loadRepo(TESTS_SRC_DIR "/data/misc", "misc");
-  test.loadRepo(TESTS_SRC_DIR "/data/OBS_zypp_svn-11.1", "zypp");
+    RepoInfo repo;
+    repo.setAlias("upd");
+    repo.addBaseUrl(Url("file://" TESTS_SRC_DIR "/data/openSUSE-11.1_updates"));
+    repo.setPriority(80);
+    repo.setGpgCheck(false);
+    testSetup->loadRepo(repo);
+    //testSetup->loadRepo(TESTS_SRC_DIR "/data/openSUSE-11.1_updates", "upd");
 
-  RepoInfo repo;
-  repo.setAlias("upd");
-  repo.addBaseUrl(Url("file://" TESTS_SRC_DIR "/data/openSUSE-11.1_updates"));
-  repo.setPriority(80);
-  repo.setGpgCheck(false);
-  test.loadRepo(repo);
-  //test.loadRepo(TESTS_SRC_DIR "/data/openSUSE-11.1_updates", "upd");
+    // resolve pool so that the satisfied status of pseudo-installed kinds becomes known
+    getZYpp()->resolver()->resolvePool();
+
+  }
+
+  std::unique_ptr<TestSetup> testSetup;
+};
+BOOST_GLOBAL_FIXTURE( TestInit );
 
-  // resolve pool so that the satisfied status of pseudo-installed kinds becomes known
-  getZYpp()->resolver()->resolvePool();
-}
 
 ///////////////////////////////////////////////////////////////////////////
 // install
@@ -141,7 +146,7 @@ BOOST_AUTO_TEST_CASE(install1)
 {
   MIL << "<=============install1==============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("nonsense");
   SolverRequester sr;
 
@@ -157,7 +162,7 @@ BOOST_AUTO_TEST_CASE(install2)
 {
   MIL << "<============install2===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("vim");
   SolverRequester sr;
 
@@ -174,7 +179,7 @@ BOOST_AUTO_TEST_CASE(install3)
 {
   MIL << "<============install3===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("zypper");
   SolverRequester sr;
 
@@ -192,7 +197,7 @@ BOOST_AUTO_TEST_CASE(install4)
 {
   MIL << "<============install4===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("netcfg");
   SolverRequester sr;
 
@@ -208,7 +213,7 @@ BOOST_AUTO_TEST_CASE(install5)
 {
   MIL << "<============install5===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("login");
   SolverRequester sr;
 
@@ -225,7 +230,7 @@ BOOST_AUTO_TEST_CASE(install6)
 {
   MIL << "<============install6===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("perl(Net::SSL)");
   SolverRequester sr;
 
@@ -234,8 +239,8 @@ BOOST_AUTO_TEST_CASE(install6)
   BOOST_CHECK(sr.hasFeedback(SolverRequester::Feedback::NOT_FOUND_NAME_TRYING_CAPS));
   BOOST_CHECK(sr.hasFeedback(SolverRequester::Feedback::ADDED_REQUIREMENT));
   BOOST_CHECK_EQUAL(sr.toInstall().size(), 0);
-  BOOST_CHECK_EQUAL(sr.requires().size(), 1);
-  BOOST_CHECK(sr.requires().find(Capability("perl(Net::SSL)")) != sr.requires().end());
+  BOOST_CHECK_EQUAL(sr.dep_requires().size(), 1);
+  BOOST_CHECK(sr.dep_requires().find(Capability("perl(Net::SSL)")) != sr.dep_requires().end());
 }
 
 // request : install --name 'perl(Net::SSL)'
@@ -245,7 +250,7 @@ BOOST_AUTO_TEST_CASE(install7)
 {
   MIL << "<============install7===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("perl(Net::SSL)");
   SolverRequester::Options sropts;
   sropts.force_by_name = true;
@@ -263,7 +268,7 @@ BOOST_AUTO_TEST_CASE(install8)
 {
   MIL << "<============install8===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("y2pmsh");
   SolverRequester::Options sropts;
   sropts.force_by_cap = true;
@@ -275,7 +280,7 @@ BOOST_AUTO_TEST_CASE(install8)
   BOOST_CHECK(!sr.hasFeedback(SolverRequester::Feedback::NOT_FOUND_NAME_TRYING_CAPS));
   BOOST_CHECK(sr.hasFeedback(SolverRequester::Feedback::ALREADY_INSTALLED));
   BOOST_CHECK(sr.toInstall().empty());
-  BOOST_CHECK(sr.requires().empty());
+  BOOST_CHECK(sr.dep_requires().empty());
 }
 
 // request : install 'info'
@@ -285,7 +290,7 @@ BOOST_AUTO_TEST_CASE(install9)
 {
   MIL << "<============install9===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("info");
   SolverRequester sr;
 
@@ -304,7 +309,7 @@ BOOST_AUTO_TEST_CASE(install10)
 {
   MIL << "<============install10===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("stellarium");
   SolverRequester sr;
 
@@ -321,7 +326,7 @@ BOOST_AUTO_TEST_CASE(install11)
 {
   MIL << "<============install11===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("diffutils");
   SolverRequester sr;
 
@@ -341,7 +346,7 @@ BOOST_AUTO_TEST_CASE(install12)
 {
   MIL << "<============install12===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("info-4.13-1.1");
   SolverRequester sr;
 
@@ -360,7 +365,7 @@ BOOST_AUTO_TEST_CASE(install13)
 {
   MIL << "<============install13===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("misc:info");
   SolverRequester sr;
 
@@ -379,7 +384,7 @@ BOOST_AUTO_TEST_CASE(install14)
 {
   MIL << "<============install14===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("info>4.12-1.109");
   SolverRequester sr;
 
@@ -399,7 +404,7 @@ BOOST_AUTO_TEST_CASE(install15)
 {
   MIL << "<============install15===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("openSUSE-release-usb-x11");
   SolverRequester sr;
 
@@ -429,7 +434,7 @@ BOOST_AUTO_TEST_CASE(install100)
 
   ApplyLock()(q);
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("zypper");
   SolverRequester sr;
 
@@ -455,7 +460,7 @@ BOOST_AUTO_TEST_CASE(install200)
 {
   MIL << "<============install200===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("cron");
   SolverRequester sr;
 
@@ -475,7 +480,7 @@ BOOST_AUTO_TEST_CASE(install201)
 {
   MIL << "<============install201===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("cron-4.1-195.0.x86_64");
   SolverRequester sr;
 
@@ -499,7 +504,7 @@ BOOST_AUTO_TEST_CASE(install300)
 {
   MIL << "<============install300===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("patch:dbus-1");
   SolverRequester sr;
 
@@ -516,7 +521,7 @@ BOOST_AUTO_TEST_CASE(install301)
 {
   MIL << "<============install301===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("patch:imap");
   SolverRequester sr;
 
@@ -533,7 +538,7 @@ BOOST_AUTO_TEST_CASE(install302)
 {
   MIL << "<============install302===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("patch:libxml2-434");
   SolverRequester sr;
   //getZYpp()->resolver()->createSolverTestcase(TESTS_BUILD_DIR "/testcase");
@@ -551,7 +556,7 @@ BOOST_AUTO_TEST_CASE(install303)
 {
   MIL << "<============install303===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("patch:libxml2");
   SolverRequester sr;
 
@@ -578,7 +583,7 @@ BOOST_AUTO_TEST_CASE(install400)
 {
   MIL << "<============install400===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("cron");
   SolverRequester::Options sropts;
   sropts.force = true;
@@ -599,7 +604,7 @@ BOOST_AUTO_TEST_CASE(install401)
 {
   MIL << "<============install401===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("info");
   SolverRequester::Options sropts;
   sropts.force = true;
@@ -621,7 +626,7 @@ BOOST_AUTO_TEST_CASE(install402)
 {
   MIL << "<============install402===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("netcfg");
   SolverRequester::Options sropts;
   sropts.force = true;
@@ -641,7 +646,7 @@ BOOST_AUTO_TEST_CASE(install403)
 {
   MIL << "<============install403===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("popt");
   SolverRequester::Options sropts;
   sropts.force = true;
@@ -670,7 +675,7 @@ BOOST_AUTO_TEST_CASE(remove1)
   PackageArgs::Options argopts;
   argopts.do_by_default = false;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("nonsense");
   PackageArgs args(rawargs, ResKind::package, argopts);
   SolverRequester sr;
@@ -690,7 +695,7 @@ BOOST_AUTO_TEST_CASE(remove2)
   PackageArgs::Options argopts;
   argopts.do_by_default = false;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("nonsense");
   PackageArgs args(rawargs, ResKind::package, argopts);
 
@@ -712,7 +717,7 @@ BOOST_AUTO_TEST_CASE(remove3)
   PackageArgs::Options argopts;
   argopts.do_by_default = false;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("mc");
   PackageArgs args(rawargs, ResKind::package, argopts);
   SolverRequester sr;
@@ -726,15 +731,15 @@ BOOST_AUTO_TEST_CASE(remove3)
 
 // request : remove mc
 // response: not installed, fall back to caps, no provider installed
-// this one is done by sr.remove(vector<string>) instead of PackageArgs
+// this one is done by sr.remove(std::vector<std::string>) instead of PackageArgs
 BOOST_AUTO_TEST_CASE(remove4)
 {
   MIL << "<==============remove4=============>" << endl;
-  // beware of implicit conversion from vector<string> to PackageArgs
+  // beware of implicit conversion from std::vector<std::string> to PackageArgs
   // if not avoided, the resulting PackageArgs would have
   // PackageArgs::Options::do_by_default == true! => args without +/- modifiers
   // would default to install/doCaps, not remove/dontCaps!
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("mc");
   SolverRequester sr;
 
@@ -750,7 +755,7 @@ BOOST_AUTO_TEST_CASE(remove4)
 BOOST_AUTO_TEST_CASE(remove5)
 {
   MIL << "<=============remove5==============>" << endl;
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("mc");
   SolverRequester::Options sropts;
   sropts.force_by_name = true;
@@ -768,7 +773,7 @@ BOOST_AUTO_TEST_CASE(remove5)
 BOOST_AUTO_TEST_CASE(remove6)
 {
   MIL << "<=============remove6==============>" << endl;
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("libzypp");
   SolverRequester sr;
 
@@ -777,7 +782,7 @@ BOOST_AUTO_TEST_CASE(remove6)
   BOOST_CHECK(sr.hasFeedback(SolverRequester::Feedback::SET_TO_REMOVE));
   BOOST_CHECK_EQUAL(sr.toRemove().size(), 1);
   BOOST_CHECK(hasPoolItem(sr.toRemove(), "libzypp", Edition("5.24.5-1.1"), Arch_x86_64));
-  BOOST_CHECK(sr.conflicts().empty());
+  BOOST_CHECK(sr.dep_conflicts().empty());
 }
 
 // request : remove --capability y2pmsh
@@ -786,7 +791,7 @@ BOOST_AUTO_TEST_CASE(remove6)
 BOOST_AUTO_TEST_CASE(remove7)
 {
   MIL << "<=============remove7==============>" << endl;
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("y2pmsh");
 
   SolverRequester::Options sropts;
@@ -797,8 +802,8 @@ BOOST_AUTO_TEST_CASE(remove7)
 
   BOOST_CHECK(sr.hasFeedback(SolverRequester::Feedback::ADDED_CONFLICT));
   BOOST_CHECK(sr.toRemove().empty());
-  BOOST_CHECK_EQUAL(sr.conflicts().size(), 1);
-  BOOST_CHECK(sr.conflicts().find(Capability("y2pmsh")) != sr.conflicts().end());
+  BOOST_CHECK_EQUAL(sr.dep_conflicts().size(), 1);
+  BOOST_CHECK(sr.dep_conflicts().find(Capability("y2pmsh")) != sr.dep_conflicts().end());
 }
 
 // request : remove onekit
@@ -810,7 +815,7 @@ BOOST_AUTO_TEST_CASE(remove7)
 BOOST_AUTO_TEST_CASE(remove8)
 {
   MIL << "<=============remove8==============>" << endl;
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("onekit");
   SolverRequester sr;
 
@@ -819,7 +824,7 @@ BOOST_AUTO_TEST_CASE(remove8)
   BOOST_CHECK(sr.hasFeedback(SolverRequester::Feedback::SET_TO_REMOVE));
   BOOST_CHECK_EQUAL(sr.toRemove().size(), 1);
   BOOST_CHECK(hasPoolItem(sr.toRemove(), "onekit", Edition("0.0.2-1"), Arch_x86_64));
-  BOOST_CHECK(sr.conflicts().empty());
+  BOOST_CHECK(sr.dep_conflicts().empty());
 }
 
 
@@ -848,7 +853,7 @@ BOOST_AUTO_TEST_CASE(update1)
 {
   MIL << "<============update1===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("vim");
   PackageArgs args(rawargs);
   SolverRequester sr;
@@ -865,7 +870,7 @@ BOOST_AUTO_TEST_CASE(update2)
 {
   MIL << "<============update2===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("nonsense");
   PackageArgs args(rawargs);
   SolverRequester sr;
@@ -880,7 +885,7 @@ BOOST_AUTO_TEST_CASE(update3)
 {
   MIL << "<============update3===============>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("info");
   SolverRequester sr;
 
@@ -900,7 +905,7 @@ BOOST_AUTO_TEST_CASE(update3)
 {
   MIL << "<===========================>" << endl;
 
-  vector<string> rawargs;
+  std::vector<std::string> rawargs;
   rawargs.push_back("");
   SolverRequester::Options sropts;
   sropts.force_by_name = true;
